##############################################################################
# list of variables included in the dataset:
# realgov: a dummy that takes value of 1 if the potential coalition corresponds to the real government formed
# largest_party_alone: a dummy that takes the value of 1 if the potential coalition is formed exclusively by the largest party
# incumbent: a dummy that takes the value of 1 if a potential coalition constituted the previous cabinet 
# minority: minority cabinet
# mwc: minimal winning coalition 
# numparty: number of parties in each potential coalition 
# ideological_range: ideological range of each potential coalition in a 2-issues policy space
# opposition_range: range of the majority opposition to the potential minority coalition in a 2-issues policy space
# formopp: number of formation opportunity (we exclude from the analysis the first formation opportunity (government De Gasperi II) in order to start to compute the incumbency variable)
# lcore: a dummy that assumes value of 1 for all the potential coalitions comprising a formation opportunity in which the DC is a core party
# core: a dummy that takes the value of 1 only if the potential coalition includes the core party
# conflict: a dummy that takes value of 1 if the previous cabinet ended due to a conflict within it or to a defeat in the parliament, 0 otherwise
##############################################################################

clear
set mem 100m
use c:\formopp_ita.dta

***separate models conditioned on the existence or not of the core

** model 1 table 2: no core/all formation opportunities *

clogit realgov minority mwc numparty ideological_range opposition_range largest_party_alone incumbent if lcore==0 & formopp>1, group(formopp)

* number of correct predicted cases using model 1

predict phat if e(sample)
sum phat if realgov==1 & lcore==0  & formopp>1
sum phat if realgov==0 & lcore==0  & formopp>1 
sort formopp phat
gen success=0
by formopp: generate caseID=_n
by formopp: egen maxcase = max(caseID)
replace success = 1 if maxcase==caseID & realgov==1 & lcore==0  & formopp>1
sum success if success==1

drop phat caseID maxcase success


** model 2 table 2: no core/all formation opportunities/no caretakers/no investiture

clogit realgov minority mwc numparty ideological_range opposition_range largest_party_alone incumbent if lcore==0 & formopp>1 & caretakers==0 & formopp!=10 & formopp!=12 & formopp!=48, group(formopp)


* number of correct predicted cases using model 2

predict phat if e(sample)
sum phat if realgov==1 & lcore==0  & formopp>1 & caretakers==0  & formopp!=10 & formopp!=12 & formopp!=48
sum phat if realgov==0 & lcore==0  & formopp>1 & caretakers==0  & formopp!=10 & formopp!=12 & formopp!=48
sort formopp phat
gen success=0
by formopp: generate caseID=_n
by formopp: egen maxcase = max(caseID) 
replace success = 1 if maxcase==caseID & realgov==1 & lcore==0  & formopp>1 & caretakers==0 & formopp!=10 & formopp!=12 & formopp!=48
sum success if success==1

drop phat caseID maxcase success

** model 3 table 2: core/all formation opportunities

clogit realgov minority mwc numparty ideological_range opposition_range largest_party_alone incumbent if lcore==1 & formopp>1, group(formopp)

* number of correct predicted cases using model 3

predict phat if e(sample)
sum phat if realgov==1 & lcore==1  & formopp>1
sum phat if realgov==0 & lcore==1  & formopp>1 
sort formopp phat
gen success=0
by formopp: generate caseID=_n
by formopp: egen maxcase = max(caseID)
replace success = 1 if maxcase==caseID & realgov==1 & lcore==1  & formopp>1
sum success if success==1

drop phat caseID maxcase success

** iia test (using the code of Martin&Stevenson 2001)

capture program drop iiatest
program define iiatest
	syntax varlist [if], per(integer) gid(varname) reps(integer)
	preserve
	matrix CHLIST=J(`reps',1,0)
	matrix DFLIST=J(`reps',1,0)
	matrix PRLIST=J(`reps',1,0)
	tokenize `varlist'
	local realgov "`1'"
	macro shift 1
	local ivs "`*'"
	clogit `realgov' `ivs' `if', group(`gid')
	qui hausman, save 
	local i `reps'
	while `i' > 0 {
		tempfile master
		qui save `master'
		display "rep number `i'"
		qui sample `per' if `realgov'==0, by(`gid')
		qui clogit `realgov' `ivs' `if', group(`gid')
		qui hausman, alleqs less 		
		qui mat DFLIST[`i',1]=`r(df)'
		if `r(chi2)' > 0 {
			qui mat PRLIST[`i',1]=chiprob(`r(df)',`r(chi2)')
			qui mat CHLIST[`i',1]=`r(chi2)'
		}
		else if `r(chi2)' <= 0 {
			qui mat PRLIST[`i',1]=0.99
			qui mat CHLIST[`i',1]=0.0
		}
		local i=`i'-1
		use `master', clear

	}

mat list CHLIST
mat CHMAT=diag(CHLIST)
scalar avstat=trace(CHMAT)/`reps'
scalar list avstat

mat list DFLIST
mat DFMAT=diag(DFLIST)
scalar avdf=trace(DFMAT)/`reps'
scalar list avdf

mat list PRLIST
mat PRMAT=diag(PRLIST)
scalar avpr=trace(PRMAT)/`reps'
scalar list avpr

end


* iia: model 1

iiatest realgov minority mwc numparty ideological_range opposition_range largest_party_alone incumbent if lcore==0 &  formopp>1, per(50) gid(formopp) reps(50)


* iia: model 2

iiatest realgov minority mwc numparty ideological_range opposition_range largest_party_alone incumbent if lcore==0 &  formopp>1 & caretakers==0 & formopp!=10 & formopp!=12 & formopp!=48, per(50) gid(formopp) reps(50)


* iia: model 3

iiatest realgov minority mwc numparty ideological_range opposition_range largest_party_alone incumbent if lcore==1 &  formopp>1, per(80) gid(formopp) reps(50)


**** full model with interactions using lcore (core in the legislature)

*** gen interactions

gen lcorexlargest_party_alone=lcore*largest_party_alone
gen lcorexincumbent=lcore*incumbent

** the costitutive term lcore was dropped according to note 9 of back, debus, dumont 2010; model without caretakers and governments that failed investiture votes

clogit realgov largest_party_alone incumbent  lcorexlargest_party_alone lcorexincumbent minority  mwc numparty ideological_range opposition_range if formopp>1 & caretakers==0 & formopp!=10 & formopp!=12 & formopp!=48, group(formopp)

* conditional marginal effect of largest_party_alone being or not the core

matrix b=e(b) 
matrix V=e(V)
scalar b1sm=b[1,1]
scalar b3sm=b[1,3]
scalar var1sm=V[1,1]
scalar var3sm=V[3,3]
scalar covb1b3sm=V[1,3]
gen beta1sm=b1sm
gen beta3sm=b3sm
gen conb1sm=b1sm+b3sm*1
gen conb0sm=b1sm+b3sm*0
gen conse1sm=sqrt(var1sm+var3sm*1^2+2*covb1b3sm*1)
gen conse0sm=sqrt(var1sm+var3sm*0^2+2*covb1b3sm*0)
gen a1sm=1.96*conse1sm
gen top1sm=conb1sm+a1sm
gen bottom1sm=conb1sm-a1sm
gen a0sm=1.96*conse0sm
gen top0sm=conb0sm+a0sm
gen bottom0sm=conb0sm-a0sm
sum beta1sm beta3sm conb1sm top1sm bottom1sm conb0sm top0sm bottom0sm


drop bottom0sm top0sm a0sm bottom1sm top1sm a1sm conse0sm conse1sm conb0sm conb1sm beta3sm beta1sm

* conditional marginal effect of incumbent administration existing or not the core

matrix b=e(b) 
matrix V=e(V)
scalar b2sm=b[1,2]
scalar b4sm=b[1,4]
scalar var2sm=V[2,2]
scalar var4sm=V[4,4]
scalar covb2b4sm=V[2,4]
gen beta2sm=b2sm
gen beta4sm=b4sm
gen conb1sm=b2sm+b4sm*1
gen conb0sm=b2sm+b4sm*0
gen conse1sm=sqrt(var2sm+var4sm*1^2+2*covb2b4sm*1)
gen conse0sm=sqrt(var2sm+var4sm*0^2+2*covb2b4sm*0)
gen a1sm=1.96*conse1sm
gen top1sm=conb1sm+a1sm
gen bottom1sm=conb1sm-a1sm
gen a0sm=1.96*conse0sm
gen top0sm=conb0sm+a0sm
gen bottom0sm=conb0sm-a0sm
sum beta2sm beta4sm conb1sm top1sm bottom1sm conb0sm top0sm bottom0sm


drop bottom0sm top0sm a0sm bottom1sm top1sm a1sm conse0sm conse1sm conb0sm conb1sm beta2sm beta2sm beta4sm


**** full model with interactions using core (core in the potential coalition)

*** gen interactions
gen corexlargest_party_alone=core*largest_party_alone
gen corexincumbent=core*incumbent

** model without caretakers and governments that failed investiture votes

clogit realgov largest_party_alone incumbent corexlargest_party_alone corexincumbent core minority  mwc numparty ideological_range opposition_range if formopp>1 & caretakers==0 & formopp!=10 & formopp!=12 & formopp!=48, group(formopp)

* conditional marginal effect of largest_party_alone being or not the core****

matrix b=e(b) 
matrix V=e(V)
scalar b1sm=b[1,1]
scalar b3sm=b[1,3]
scalar var1sm=V[1,1]
scalar var3sm=V[3,3]
scalar covb1b3sm=V[1,3]
gen beta1sm=b1sm
gen beta3sm=b3sm
gen conb1sm=b1sm+b3sm*1
gen conb0sm=b1sm+b3sm*0
gen conse1sm=sqrt(var1sm+var3sm*1^2+2*covb1b3sm*1)
gen conse0sm=sqrt(var1sm+var3sm*0^2+2*covb1b3sm*0)
gen a1sm=1.96*conse1sm
gen top1sm=conb1sm+a1sm
gen bottom1sm=conb1sm-a1sm
gen a0sm=1.96*conse0sm
gen top0sm=conb0sm+a0sm
gen bottom0sm=conb0sm-a0sm
sum beta1sm beta3sm conb1sm top1sm bottom1sm conb0sm top0sm bottom0sm


drop bottom0sm top0sm a0sm bottom1sm top1sm a1sm conse0sm conse1sm conb0sm conb1sm beta3sm beta1sm

* conditional marginal effect of incumbent administration existing or not the core

matrix b=e(b) 
matrix V=e(V)
scalar b2sm=b[1,2]
scalar b4sm=b[1,4]
scalar var2sm=V[2,2]
scalar var4sm=V[4,4]
scalar covb2b4sm=V[2,4]
gen beta2sm=b2sm
gen beta4sm=b4sm
gen conb1sm=b2sm+b4sm*1
gen conb0sm=b2sm+b4sm*0
gen conse1sm=sqrt(var2sm+var4sm*1^2+2*covb2b4sm*1)
gen conse0sm=sqrt(var2sm+var4sm*0^2+2*covb2b4sm*0)
gen a1sm=1.96*conse1sm
gen top1sm=conb1sm+a1sm
gen bottom1sm=conb1sm-a1sm
gen a0sm=1.96*conse0sm
gen top0sm=conb0sm+a0sm
gen bottom0sm=conb0sm-a0sm
sum beta2sm beta4sm conb1sm top1sm bottom1sm conb0sm top0sm bottom0sm


drop bottom0sm top0sm a0sm bottom1sm top1sm a1sm conse0sm conse1sm conb0sm conb1sm beta2sm beta2sm beta4sm

**** adding an interaction between conflict and incumbent as in Martin and Stevenson 2010

*** gen conflict

gen conflict=0
replace conflict=1 if formopp==1
replace conflict=1 if formopp==2

replace conflict=1 if formopp==6

replace conflict=1 if formopp==8
replace conflict=1 if formopp==10
replace conflict=1 if formopp==11
replace conflict=1 if formopp==12
replace conflict=1 if formopp==13
replace conflict=1 if formopp==14
replace conflict=1 if formopp==15
replace conflict=1 if formopp==16
replace conflict=1 if formopp==17
replace conflict=1 if formopp==18
replace conflict=1 if formopp==21

replace conflict=1 if formopp==24
replace conflict=1 if formopp==26
replace conflict=1 if formopp==27
replace conflict=1 if formopp==28

replace conflict=1 if formopp==30
replace conflict=1 if formopp==32
replace conflict=1 if formopp==33
replace conflict=1 if formopp==34
replace conflict=1 if formopp==35

replace conflict=1 if formopp==38
replace conflict=1 if formopp==39
replace conflict=1 if formopp==40
replace conflict=1 if formopp==41
replace conflict=1 if formopp==42

replace conflict=1 if formopp==44

replace conflict=1 if formopp==47
replace conflict=1 if formopp==49
replace conflict=1 if formopp==50
replace conflict=1 if formopp==51
replace conflict=1 if formopp==53

gen conflictxincumbent=conflict*incumbent

** model 2 as in table 2 plus interaction with conflict

clogit realgov incumbent largest_party_alone conflictxincumbent minority mwc numparty ideological_range opposition_range if lcore==0 & formopp>1 & caretakers==0 & formopp!=10 & formopp!=12 & formopp!=48, group(formopp)

* conditional marginal effect of incumbent

matrix b=e(b) 
matrix V=e(V)
scalar b1sm=b[1,1]
scalar b3sm=b[1,3]
scalar var1sm=V[1,1]
scalar var3sm=V[3,3]
scalar covb1b3sm=V[1,3]
gen beta1sm=b1sm
gen beta3sm=b3sm
gen conb1sm=b1sm+b3sm*1
gen conb0sm=b1sm+b3sm*0
gen conse1sm=sqrt(var1sm+var3sm*1^2+2*covb1b3sm*1)
gen conse0sm=sqrt(var1sm+var3sm*0^2+2*covb1b3sm*0)
gen a1sm=1.96*conse1sm
gen top1sm=conb1sm+a1sm
gen bottom1sm=conb1sm-a1sm
gen a0sm=1.96*conse0sm
gen top0sm=conb0sm+a0sm
gen bottom0sm=conb0sm-a0sm
sum beta1sm beta3sm conb1sm top1sm bottom1sm conb0sm top0sm bottom0sm

drop bottom0sm top0sm a0sm bottom1sm top1sm a1sm conse0sm conse1sm conb0sm conb1sm beta3sm beta1sm

** model 3 as in table 2 plus interaction with conflict

clogit realgov incumbent largest_party_alone conflictxincumbent minority mwc numparty ideological_range opposition_range if lcore==1 & formopp>1, group(formopp)

* conditional marginal effect of incumbent

matrix b=e(b) 
matrix V=e(V)
scalar b1sm=b[1,1]
scalar b3sm=b[1,3]
scalar var1sm=V[1,1]
scalar var3sm=V[3,3]
scalar covb1b3sm=V[1,3]
gen beta1sm=b1sm
gen beta3sm=b3sm
gen conb1sm=b1sm+b3sm*1
gen conb0sm=b1sm+b3sm*0
gen conse1sm=sqrt(var1sm+var3sm*1^2+2*covb1b3sm*1)
gen conse0sm=sqrt(var1sm+var3sm*0^2+2*covb1b3sm*0)
gen a1sm=1.96*conse1sm
gen top1sm=conb1sm+a1sm
gen bottom1sm=conb1sm-a1sm
gen a0sm=1.96*conse0sm
gen top0sm=conb0sm+a0sm
gen bottom0sm=conb0sm-a0sm
sum beta1sm beta3sm conb1sm top1sm bottom1sm conb0sm top0sm bottom0sm

drop bottom0sm top0sm a0sm bottom1sm top1sm a1sm conse0sm conse1sm conb0sm conb1sm beta3sm beta1sm

